@@ -36,15 +36,15 @@ public:
     @param The number to convert
     @return The letter string representation of the number.
   */
-    QString getLetterString(int itemNumber);
+    Q_REQUIRED_RESULT QString getLetterString(int itemNumber);
 
-    QString getRomanString(int itemNumber);
+    Q_REQUIRED_RESULT QString getRomanString(int itemNumber);
 
     /**
     Gets a block of references in the body of the text.
     This is an ordered list of links and images in the text.
   */
-    QString getReferences();
+    Q_REQUIRED_RESULT QString getReferences();
 
     QStringList m_urls;
     QList<QTextListFormat::Style> currentListItemStyles;
@@ -421,7 +421,30 @@ void PlainTextMarkupBuilder::beginForeground(const QBrush &brush)
 
 void PlainTextMarkupBuilder::beginHeader(int level)
 {
-    Q_UNUSED(level);
+    Q_D(PlainTextMarkupBuilder);
+    switch (level) {
+    case 1:
+        d->m_text.append(QStringLiteral("# "));
+        break;
+    case 2:
+        d->m_text.append(QStringLiteral("## "));
+        break;
+    case 3:
+        d->m_text.append(QStringLiteral("### "));
+        break;
+    case 4:
+        d->m_text.append(QStringLiteral("#### "));
+        break;
+    case 5:
+        d->m_text.append(QStringLiteral("##### "));
+        break;
+    case 6:
+        d->m_text.append(QStringLiteral("###### "));
+        break;
+    default:
+        break;
+    }
+
 }
 
 void PlainTextMarkupBuilder::beginTable(qreal cellpadding, qreal cellspacing,
@@ -470,7 +493,30 @@ void PlainTextMarkupBuilder::endForeground()
 
 void PlainTextMarkupBuilder::endHeader(int level)
 {
-    Q_UNUSED(level)
+    Q_D(PlainTextMarkupBuilder);
+    qDebug() << " void PlainTextMarkupBuilder::endHeader(int level)"<< level;
+    switch (level) {
+    case 1:
+        d->m_text.append(QStringLiteral(" #\n"));
+        break;
+    case 2:
+        d->m_text.append(QStringLiteral(" ##\n"));
+        break;
+    case 3:
+        d->m_text.append(QStringLiteral(" ###\n"));
+        break;
+    case 4:
+        d->m_text.append(QStringLiteral(" ####\n"));
+        break;
+    case 5:
+        d->m_text.append(QStringLiteral(" #####\n"));
+        break;
+    case 6:
+        d->m_text.append(QStringLiteral(" ######\n"));
+        break;
+    default:
+        break;
+    }
 }
 
 void PlainTextMarkupBuilder::endTable()
