@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,7 +33,7 @@ public:
     SelectSpecialCharDialogPrivate(SelectSpecialCharDialog *qq)
         : q(qq)
     {
-        q->setWindowTitle(i18n("Select Special Characters"));
+        q->setWindowTitle(i18nc("@title:window", "Select Special Characters"));
 
         QVBoxLayout *lay = new QVBoxLayout(q);
 
