@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,10 +22,9 @@
 #include "kpimtextedit_debug.h"
 #include <QIcon>
 #include <KLocalizedString>
-#include <kmessagebox.h>
-#include <klineedit.h>
+#include <KMessageBox>
 #include <KColorScheme>
-
+#include <QLineEdit>
 #include <QTimer>
 #include <QToolButton>
 #include <QEvent>
