@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,11 +20,11 @@
 #include "richtexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
 
-#include <kmessagebox.h>
-#include <klineedit.h>
+#include <KMessageBox>
 #include <KColorScheme>
 
 #include <QTextEdit>
+#include <QLineEdit>
 #include <QRegularExpression>
 
 using namespace KPIMTextEdit;
